/******************************************************************************/
/* LINKER COMMAND FILE FOR MSPBoot BOOTLOADER USING msp430fr5994  */
/* File generated with MSPBootLinkerGen.py on 2020-03-05 */
/*----------------------------------------------------------------------------*/


/****************************************************************************/
/* SPECIFY THE SYSTEM MEMORY MAP                                            */
/****************************************************************************/
/* The following definitions can be changed to customize the memory map for a different device
 *   or other adjustments
 *  Note that the changes should match the definitions used in MEMORY and SECTIONS
 *
 */
/* RAM Memory Addresses */
__RAM_Start = 0x1c00;                 /* RAM Start */
__RAM_End = 0x2bff;                     /* RAM End */
    /* RAM shared between App and Bootloader, must be reserved */
    PassWd = 0x1c00;                 /* Password sent by App to force boot  mode */
    StatCtrl = 0x1c02;             /* Status and Control  byte used by Comm */
    CI_State_Machine = 0x1c03;         /*  State machine variable used by Comm */
    CI_Callback_ptr = 0x1c04;   /* Pointer to Comm callback structure */
    /* Unreserved RAM used for Bootloader or App purposes */
    _NonReserved_RAM_Start = 0x1c08; /* Non-reserved RAM */

/* Flash memory addresses */ 
__Flash_Start = 0x4000;             /* Start of Application area */
   /* Reserved Flash locations for Bootloader Area */
    __Boot_Start = 0xf000;         /* Boot flash */
    __Boot_Reset = 0xFFFE;                          /* Boot reset vector */
    __Boot_VectorTable = 0xFF90;      /* Boot vector table */
    __Boot_SharedCallbacks_Len = 0x10; /* Length of shared callbacks (2 calls =4B(msp430) or 8B(msp430x) */
    __Boot_SharedCallbacks = 0xff70; /* Start of Shared callbacks */
     _BOOT_APPVECTOR = __Boot_SharedCallbacks;       /* Definition for application table             */
    _Appl_Vector_Start = 0xef90; /* Interrupt table */
    /* Reserved Flash locations for Application Area */
 
/* MEMORY definition, adjust based on definitions above */
MEMORY
{
    SFR                     : origin = 0x0000, length = 0x0010
    PERIPHERALS_8BIT        : origin = 0x0010, length = 0x00F0
    PERIPHERALS_16BIT       : origin = 0x0100, length = 0x0100
    // RAM from _NonReserved_RAM_Start - __RAM_End
    RAM                     : origin = 0x1c08, length = 0xff8
    // Flash from _App_Start -> (APP_VECTORS-1)
    FLASH                   : origin = 0x4003, length = 0xaf8d
    FLASH2                  : origin = 0x10000, length = 0x34000
    // Interrupt table from  _App_Vector_Start->(RESET-1)
    INT00            : origin = 0xef90, length = 0x0002
    INT01            : origin = 0xef92, length = 0x0002
    INT02            : origin = 0xef94, length = 0x0002
    INT03            : origin = 0xef96, length = 0x0002
    INT04            : origin = 0xef98, length = 0x0002
    INT05            : origin = 0xef9a, length = 0x0002
    INT06            : origin = 0xef9c, length = 0x0002
    INT07            : origin = 0xef9e, length = 0x0002
    INT08            : origin = 0xefa0, length = 0x0002
    INT09            : origin = 0xefa2, length = 0x0002
    INT10            : origin = 0xefa4, length = 0x0002
    INT11            : origin = 0xefa6, length = 0x0002
    INT12            : origin = 0xefa8, length = 0x0002
    INT13            : origin = 0xefaa, length = 0x0002
    INT14            : origin = 0xefac, length = 0x0002
    INT15            : origin = 0xefae, length = 0x0002
    INT16            : origin = 0xefb0, length = 0x0002
    INT17            : origin = 0xefb2, length = 0x0002
    INT18            : origin = 0xefb4, length = 0x0002
    INT19            : origin = 0xefb6, length = 0x0002
    INT20            : origin = 0xefb8, length = 0x0002
    INT21            : origin = 0xefba, length = 0x0002
    INT22            : origin = 0xefbc, length = 0x0002
    INT23            : origin = 0xefbe, length = 0x0002
    INT24            : origin = 0xefc0, length = 0x0002
    INT25            : origin = 0xefc2, length = 0x0002
    INT26            : origin = 0xefc4, length = 0x0002
    INT27            : origin = 0xefc6, length = 0x0002
    INT28            : origin = 0xefc8, length = 0x0002
    INT29            : origin = 0xefca, length = 0x0002
    INT30            : origin = 0xefcc, length = 0x0002
    INT31            : origin = 0xefce, length = 0x0002
    INT32            : origin = 0xefd0, length = 0x0002
    INT33            : origin = 0xefd2, length = 0x0002
    INT34            : origin = 0xefd4, length = 0x0002
    INT35            : origin = 0xefd6, length = 0x0002
    INT36            : origin = 0xefd8, length = 0x0002
    INT37            : origin = 0xefda, length = 0x0002
    INT38            : origin = 0xefdc, length = 0x0002
    INT39            : origin = 0xefde, length = 0x0002
    INT40            : origin = 0xefe0, length = 0x0002
    INT41            : origin = 0xefe2, length = 0x0002
    INT42            : origin = 0xefe4, length = 0x0002
    INT43            : origin = 0xefe6, length = 0x0002
    INT44            : origin = 0xefe8, length = 0x0002
    INT45            : origin = 0xefea, length = 0x0002
    INT46            : origin = 0xefec, length = 0x0002
    INT47            : origin = 0xefee, length = 0x0002
    INT48            : origin = 0xeff0, length = 0x0002
    INT49            : origin = 0xeff2, length = 0x0002
    INT50            : origin = 0xeff4, length = 0x0002
    INT51            : origin = 0xeff6, length = 0x0002
    INT52            : origin = 0xeff8, length = 0x0002
    INT53            : origin = 0xeffa, length = 0x0002
    INT54            : origin = 0xeffc, length = 0x0002
    
    // App reset from _App_Reset_Vector
    RESET                   : origin = 0xeffe, length = 0x0002
}

/****************************************************************************/
/* SPECIFY THE SECTIONS ALLOCATION INTO MEMORY                              */
/****************************************************************************/

SECTIONS
{
    .bss        : {} > RAM                /* GLOBAL & STATIC VARS              */
    .data       : {} > RAM                /* GLOBAL & STATIC VARS              */
    .sysmem     : {} > RAM                /* DYNAMIC MEMORY ALLOCATION AREA    */
    .stack      : {} > RAM (HIGH)         /* SOFTWARE SYSTEM STACK             */

    .text:_isr        : {}  > FLASH            /* Code ISRs                         */
    #ifndef __LARGE_DATA_MODEL__
	.text       : {} >> FLASH            /* CODE                 */
    #else 
	.text       : {} >> FLASH | FLASH2      /* CODE                 */
    #endif 
       .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ 
    #ifndef __LARGE_DATA_MODEL__ 
      .const      : {} >> FLASH       /* CONSTANT DATA        */ 
    #else 
      .const      : {} >> FLASH2 | FLASH    /* CONSTANT DATA        */ 
    #endif 

    .cio        : {} > RAM                /* C I/O BUFFER                      */

    /* MSP430 INTERRUPT VECTORS          */
    .int00       : {}               > INT00
    .int01       : {}               > INT01
    .int02       : {}               > INT02
    .int03       : {}               > INT03
    .int04       : {}               > INT04
    .int05       : {}               > INT05
    .int06       : {}               > INT06
    .int07       : {}               > INT07
    .int08       : {}               > INT08
    .int09       : {}               > INT09
    .int10       : {}               > INT10
    .int11       : {}               > INT11
    .int12       : {}               > INT12
    .int13       : {}               > INT13
    .int14       : {}               > INT14
    .int15       : {}               > INT15
    .int16       : {}               > INT16
    .int17       : {}               > INT17
    LEA_SC       : { * ( .int18 ) } > INT18 type = VECT_INIT
    PORT8        : { * ( .int19 ) } > INT19 type = VECT_INIT
    PORT7        : { * ( .int20 ) } > INT20 type = VECT_INIT
    EUSCI_B3     : { * ( .int21 ) } > INT21 type = VECT_INIT
    EUSCI_B2     : { * ( .int22 ) } > INT22 type = VECT_INIT
    EUSCI_B1     : { * ( .int23 ) } > INT23 type = VECT_INIT
    EUSCI_A3     : { * ( .int24 ) } > INT24 type = VECT_INIT
    EUSCI_A2     : { * ( .int25 ) } > INT25 type = VECT_INIT
    PORT6        : { * ( .int26 ) } > INT26 type = VECT_INIT
    PORT5        : { * ( .int27 ) } > INT27 type = VECT_INIT
    TIMER4_A1    : { * ( .int28 ) } > INT28 type = VECT_INIT
    TIMER4_A0    : { * ( .int29 ) } > INT29 type = VECT_INIT
    AES256       : { * ( .int30 ) } > INT30 type = VECT_INIT
    RTC_C        : { * ( .int31 ) } > INT31 type = VECT_INIT
    PORT4        : { * ( .int32 ) } > INT32 type = VECT_INIT
    PORT3        : { * ( .int33 ) } > INT33 type = VECT_INIT
    TIMER3_A1    : { * ( .int34 ) } > INT34 type = VECT_INIT
    TIMER3_A0    : { * ( .int35 ) } > INT35 type = VECT_INIT
    PORT2        : { * ( .int36 ) } > INT36 type = VECT_INIT
    TIMER2_A1    : { * ( .int37 ) } > INT37 type = VECT_INIT
    TIMER2_A0    : { * ( .int38 ) } > INT38 type = VECT_INIT
    PORT1        : { * ( .int39 ) } > INT39 type = VECT_INIT
    TIMER1_A1    : { * ( .int40 ) } > INT40 type = VECT_INIT
    TIMER1_A0    : { * ( .int41 ) } > INT41 type = VECT_INIT
    DMA          : { * ( .int42 ) } > INT42 type = VECT_INIT
    EUSCI_A1     : { * ( .int43 ) } > INT43 type = VECT_INIT
    TIMER0_A1    : { * ( .int44 ) } > INT44 type = VECT_INIT
    TIMER0_A0    : { * ( .int45 ) } > INT45 type = VECT_INIT
    ADC12_B      : { * ( .int46 ) } > INT46 type = VECT_INIT
    EUSCI_B0     : { * ( .int47 ) } > INT47 type = VECT_INIT
    EUSCI_A0     : { * ( .int48 ) } > INT48 type = VECT_INIT
    WDT          : { * ( .int49 ) } > INT49 type = VECT_INIT
    TIMER0_B1    : { * ( .int50 ) } > INT50 type = VECT_INIT
    TIMER0_B0    : { * ( .int51 ) } > INT51 type = VECT_INIT
    COMP_E       : { * ( .int52 ) } > INT52 type = VECT_INIT
    UNMI         : { * ( .int53 ) } > INT53 type = VECT_INIT
    SYSNMI       : { * ( .int54 ) } > INT54 type = VECT_INIT

    .reset       : {}               > RESET  /* MSP430 RESET VECTOR                 */
}

/****************************************************************************/
/* INCLUDE PERIPHERALS MEMORY MAP                                           */
/****************************************************************************/

-l msp430fr5994.cmd

