# --COPYRIGHT--,BSD-3-Clause
#  Copyright (c) 2019, Texas Instruments Incorporated
#  All rights reserved.
# 
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions
#  are met:
# 
#  *  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
# 
#  *  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
# 
#  *  Neither the name of Texas Instruments Incorporated nor the names of
#     its contributors may be used to endorse or promote products derived
#     from this software without specific prior written permission.
# 
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
#  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
#  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# --/COPYRIGHT--

#Python script used to generate linker files for MSPFRBoot
#   Check help for usage
#

import linecache
import sys, getopt
import datetime
import string
import shutil


device=''
data_array=[]
memory_type="FLASH"
shared_vectors=0

print( "\n MSP430FRBootLinkerGen.py V1.0 \n")
print( "Texas Instruments Inc 2019 \n")

def usage():
    print("Usage: ([] means optional)%s " % (sys.argv[0]))
    print("  -h, --help            help file")
    print("  -f, --file            out put file's name")
    print("  -l, --lnk_file        lnk_msp430.cmd file")
    print("  -b, --boot_size       boot code size") 
    print(" [-d, --dual_image]     boot mode") 
    print(" [-s, --shared_vectors] shared vectors number") 

#print("sys.argv=|%s|" % sys.argv)
def get_device(link_file):
	with open(link_file) as file_object:
		lines = file_object.readlines()
	for line in lines:
		if (line[0]=='-') and (line[1]=='l'):
			line=line.replace('.',' ')
			data_array=line.split()
#			print(data_array)			
			return 	data_array[1]
def getAddrLenInFile(link_file, memory):
	return_list=[]
	with open(link_file) as file_object:
		lines = file_object.readlines()
	for line in lines:	
		if line.find("    " + memory + "         ")>=0:
			line=line.replace(',',' ')			
			data_array=line.split()
			return_list.append(data_array[4])
			return_list.append(data_array[7])				
			return 	return_list
	return return_list

def replacetextinFile(file,old_str,new_str):
	file_data = ""
	with open(file, "r") as f:
		for line in f:
			if old_str in line:
				line = line.replace(old_str,new_str)
			file_data += line
	with open(file,"w") as f:
		f.write(file_data)			

def getVectors(link_file):
	return_list=''
	vectors_found = 0
	with open(link_file) as file_object:
		lines = file_object.readlines()
	for line in lines:	
		if line.find(".int00  ")>=0:
			vectors_found=1
			return_list='/* MSP430 INTERRUPT VECTORS          */\n'
		if line.find(".reset  ")>=0:		
			return 	return_list			
		if vectors_found==1:
			return_list=return_list+line
			
try:
    opts, args = getopt.gnu_getopt(sys.argv[1:], "hf:l:b:ds:", ['help','file=','lnk_file=',"boot_size=",'dual_image',"shared_vectors="])
#    print("opts=|%s|" % opts)
#    print("args=|%s|" % args)
except getopt.GetoptError as ee:
    print (ee)
    usage()
    sys.exit()
dual_image = 0
#output_filename = ''
for op, value in opts:
    if op in "-h" or op == "--help":
        usage()
        sys.exit()
    if op in ("-f","--file"):
        output_filename = value   
        print("output_filename:  %s" %output_filename + "_xxx.cmd")     
    if op in ("-l","--lnk_file"):
        lnk_filename = value
        print("lnk_filename:  %s" %lnk_filename) 
    if op in ("-b","--boot_size"):
        boot_size = int(value,16)
        print("boot_size:  0x%x" %boot_size)
    if op in ("-d","--dual_image"):
        dual_image = 1
        print("Dual image mode")
    if op in ("-s","--shared_vectors"):
        shared_vectors = value     
        print("shared_vectors: 0x%x" %shared_vectors)
           
#print("output_filename:  %s" %output_filename)        
if ((len(opts)<3) or (len(opts)>5)):
    print("Input parameters error!")
    usage()
    sys.exit()
 

if (boot_size % 0x400 != 0) or (boot_size==0):
	print("Error: Boot size must be a multiple of 0x400!")
	usage()
	sys.exit()
	
# get the device number
device=get_device(lnk_filename)
print("Device name:  %s" %device)
if device.find("fr")>=0:
	memory_type="FRAM"
#print(memory_type)
flash_data = getAddrLenInFile(lnk_filename, memory_type)
#print(flash_data)
flash_data2 = getAddrLenInFile(lnk_filename, memory_type + "2")
if flash_data2==[]:
	flash_data2.append('0x0')
	flash_data2.append('0x0')	
ram_data = getAddrLenInFile(lnk_filename, "RAM")
vectors_data = getAddrLenInFile(lnk_filename, "INT00")

# get the memory type, flash or FRAM

flash_vectors_addr=vectors_data[0]
flash_boot_start_addr=0x10000-boot_size
vector_size=0xfffe-int(vectors_data[0],16)
shared_vectors_size=16
if(shared_vectors):
	shared_vectors_size=int(shared_vectors,16)*2
curr_time = datetime.datetime.now()
time_str = curr_time.strftime("%Y-%m-%d")
print(time_str+"\n")

if flash_boot_start_addr < int(flash_data[0],16) + vector_size:
	print("Error: Boot size too large to fit in lower memory.")
	sys.exit()
RAM_start_addr=int(ram_data[0],16)
RAM_end_addr=int(ram_data[0],16)+int(ram_data[1],16)-1
#print(hex(RAM_start_addr),hex(RAM_end_addr))

flex_type = ''
dual_start_addr = 0x0
appl_start_addr = int(flash_data[0],16)
#print("test")
#print(flash_data)
#flash_data[0] FRAM start address; flash_data[1] FRAM Size
#flash_data2[0] 0x10000; flash_data2[1] FRAM2 Size
if (dual_image):
	dual_size = 0x10000-int(flash_data[0],16) + int(flash_data2[1],16) - boot_size 
#	print(hex(dual_size))
	if int(flash_data2[1],16)!=0:
		dual_end_addr = int(flash_data2[0],16) + int(flash_data2[1],16) - 1
	else:
		dual_end_addr = flash_boot_start_addr-1
#	print(hex(dual_end_addr))
	if (dual_size/2 + int(flash_data[0],16))<flash_boot_start_addr:
		dual_start_addr = int(flash_data[0],16) + int(dual_size/2)
		flex_type = "download"
		flex_start_addr = dual_start_addr
		flex_end_addr = flash_boot_start_addr - 1		
		appl_end_addr = flex_start_addr - 1
	else:
#		dual_start_addr = dual_end_addr - int(dual_size/2)
		dual_start_addr = int(flash_data2[0],16)+int(flash_data2[1],16) - int(dual_size/2)
		flex_type = "application"
		flex_start_addr = int(flash_data2[0],16)
		flex_end_addr = dual_start_addr-1
		appl_end_addr = flash_boot_start_addr-1

	print("App + Download Size: 0x%x" % dual_size)
	print("Download start:      0x%x" % dual_start_addr)
	print("App start:           0x%x" % appl_start_addr)
	print("Flex start:          0x%x" % flex_start_addr)
	print("Boot start:          0x%x" % flash_boot_start_addr)
else:
	appl_end_addr = flash_boot_start_addr - 1
	flex_start_addr = int(flash_data2[0],16)
	if int(flash_data2[1],16)!=0:
		flex_end_addr = int(flash_data2[0],16) + int(flash_data2[1],16) - 1
	else:
		flex_end_addr = 0xffff
	
	print("App start:     0x%x" % appl_start_addr)
	print("appl_end_addr: 0x%x" % appl_end_addr)
	print("Flex start:    0x%x" % flex_start_addr)
	print("flex_end_addr: 0x%x" % flash_boot_start_addr)
vector_addr = appl_end_addr - 1 - vector_size
print("vector_addr:      0x%x" % vector_addr)

filename_OutBootCCS = output_filename + "_Boot.cmd"
filename_OutAppCCS = output_filename + "_App.cmd"
filename_OutBootIAR = output_filename + "_Boot.xcl"
filename_OutAppIAR = output_filename + "_App.xcl"
	
shutil.copyfile('template_Boot_CCS_flex.tmpl', filename_OutBootCCS)
shutil.copyfile('template_App_CCS_flex.tmpl', filename_OutAppCCS)
shutil.copyfile('template_Boot_IAR_flex.tmpl', filename_OutBootIAR)
shutil.copyfile('template_App_IAR_flex.tmpl', filename_OutAppIAR)

##### Replace text in Boot CCS file#######################################################################################################
replacetextinFile(filename_OutBootCCS,'<DATE>', time_str)
replacetextinFile(filename_OutBootCCS,'<DEVICE>', device)
replacetextinFile(filename_OutBootCCS,'<RAM_START_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutBootCCS,'<RAM_END_ADDR>', str(hex(RAM_end_addr)))
replacetextinFile(filename_OutBootCCS,'<RAM_PASSWD_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutBootCCS,'<RAM_STATCTRL_ADDR>', str(hex(RAM_start_addr+2)))
replacetextinFile(filename_OutBootCCS,'<RAM_CISM_ADDR>', str(hex(RAM_start_addr+3)))
replacetextinFile(filename_OutBootCCS,'<RAM_CALLBACKPTR_ADDR>', str(hex(RAM_start_addr+4)))
replacetextinFile(filename_OutBootCCS,'<RAM_UNUSED_ADDR>', str(hex(RAM_start_addr+8)))

replacetextinFile(filename_OutBootCCS,'<APPL_START_ADDR>', str(hex(appl_start_addr)))
replacetextinFile(filename_OutBootCCS,'<APPL_END_ADDR>', str(hex(appl_end_addr)))
replacetextinFile(filename_OutBootCCS,'<FLEX_START_ADDR>', str(hex(flex_start_addr)))
replacetextinFile(filename_OutBootCCS,'<FLEX_END_ADDR>', str(hex(flex_end_addr)))

replacetextinFile(filename_OutBootCCS,'<VECTOR_ADDR>', str(hex(vector_addr)))

if dual_image:
	if flex_type =='download':
		if int(flash_data2[1],16)==0:		
			replacetextinFile(filename_OutBootCCS,'<DOWNLOAD>', "_Down_Start = "+str(hex(flex_start_addr))+";\
			/* Download Area */\n_Down_End = " + str(hex(dual_end_addr))\
			+ ';        /*End of Download Area */\n')

			replacetextinFile(filename_OutBootCCS,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))\
			+ '-0xffff*/\n')
		else:
			replacetextinFile(filename_OutBootCCS,'<DOWNLOAD>', "_Down_Start = 0x10000;\
			/* Download Area */\n_Down_End = " + str(hex(dual_end_addr))\
			+ ';        /*End of Download Area */\n')			
			replacetextinFile(filename_OutBootCCS,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+' & 0x10000-'\
			+ str(hex(dual_end_addr))+'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))\
			+ '-0xffff*/\n')			
		replacetextinFile(filename_OutBootCCS,'<CHECKSUMS>', '\
		_Appl_Reset_Vector = (_Flex_Start - 2);\n\
		_Down_Checksum = (_Flex_Start);\n\
	    _Down_Checksum_8 = (_Flex_Start+2);\n\
	    _Down_Start_Memory = (_Flex_Start+3);\n\
	    _Down_CRC_Size1 = (_Flex_End - _Down_Start_Memory + 1);\n\
	    _Down_CRC_Size2 = (_Down_End - _Down_Start + 1);\n\
	    _Down_Offset_Size = (_Appl_Start +_Flex_End - _Flex_Start);\n\
	    _Down_Offset1 = (_Flex_Start - _Appl_Start);\n\
	    _Down_Offset2 = (_Down_Start + _Flex_Start - _Appl_Start - __Boot_Start);\n'                    
		    )
	else:
		replacetextinFile(filename_OutBootCCS,'<DOWNLOAD>', '_Down_Start = '\
		+str(hex(dual_start_addr))+';		/* Download Area */\n_Down_End = ' + str(hex(dual_end_addr))\
		+ ';        /*End of Download Area */\n')
		replacetextinFile(filename_OutBootCCS,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & '+ str(hex(flex_start_addr))+'-'+ str(hex(flex_end_addr))\
		+'*/\n/* Download area: '+ str(hex(dual_start_addr))+'-'+str(hex(dual_end_addr))\
		+'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr)) + '-0xffff*/\n')
#		print("dual_start_addr:  %x" %dual_start_addr)
		replacetextinFile(filename_OutBootCCS,'<CHECKSUMS>', '\
		_Appl_Reset_Vector = (__Boot_Start - 2);\n\
		_Down_Checksum = (_Down_Start);\n\
	    _Down_Checksum_8 = (_Down_Start+2);\n\
	    _Down_Start_Memory = (_Down_Start+3);\n\
	    _Down_CRC_Size1 = (_Down_End - _Down_Start_Memory + 1);\n\
	    _Down_CRC_Size2 = (_Down_End - _Down_Start_Memory + 1);\n\
	    _Down_Offset_Size = (__Boot_Start - 1);\n\
	    _Down_Offset1 = (_Down_Start - _Appl_Start);\n\
	    _Down_Offset2 = (__Boot_Start - _Appl_Start + _Down_Start - _Flex_Start);\n'                    
		    )
else:
	replacetextinFile(filename_OutBootCCS,'<DOWNLOAD>', ' ')
	replacetextinFile(filename_OutBootCCS,'<CHECKSUMS>', '    _Appl_Reset_Vector = (__Boot_Start - 2);\n')
	replacetextinFile(filename_OutBootCCS,'<VECTOR_SIZE>', str(hex(vector_size)))
	replacetextinFile(filename_OutBootCCS,'<BOOT1>', ' ')
	
replacetextinFile(filename_OutBootCCS,'<FLASH_BOOT_START_ADDR>', str(hex(flash_boot_start_addr)))
replacetextinFile(filename_OutBootCCS,'<FLASH_VECTORS_ADDR>', flash_vectors_addr)
replacetextinFile(filename_OutBootCCS,'<SHARED_VECTORS_SIZE>', str(hex(shared_vectors_size)))
shared_vector_addr = int(flash_data[0],16) + int(flash_data[1],16) - shared_vectors_size
replacetextinFile(filename_OutBootCCS,'<SHARED_VECTORS_ADDR>', str(hex(shared_vector_addr)))

replacetextinFile(filename_OutBootCCS,'<RAM_LEN>', str(hex(RAM_end_addr - (RAM_start_addr+8)+1)))
replacetextinFile(filename_OutBootCCS,'<FLASH_BOOT_LEN>', str(hex(shared_vector_addr - flash_boot_start_addr)))
replacetextinFile(filename_OutBootCCS,'<FLASH_VECTORS_LEN>', str(0xFFFE - int(flash_vectors_addr,16)))

##### Replace text in App CCS file###########################################################################################################
replacetextinFile(filename_OutAppCCS,'<DATE>', time_str)
replacetextinFile(filename_OutAppCCS,'<DEVICE>', device)
replacetextinFile(filename_OutAppCCS,'<RAM_START_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutAppCCS,'<RAM_END_ADDR>', str(hex(RAM_end_addr)))

replacetextinFile(filename_OutAppCCS,'<RAM_PASSWD_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutAppCCS,'<RAM_STATCTRL_ADDR>', str(hex(RAM_start_addr+2)))
replacetextinFile(filename_OutAppCCS,'<RAM_CISM_ADDR>', str(hex(RAM_start_addr+3)))
replacetextinFile(filename_OutAppCCS,'<RAM_CALLBACKPTR_ADDR>', str(hex(RAM_start_addr+4)))
replacetextinFile(filename_OutAppCCS,'<RAM_UNUSED_ADDR>', str(hex(RAM_start_addr+8)))
replacetextinFile(filename_OutAppCCS,'<RAM_LEN>', str(hex(RAM_end_addr-RAM_start_addr-7)))

replacetextinFile(filename_OutAppCCS,'<APPL_START_ADDR>', str(hex(appl_start_addr)))
#replacetextinFile(filename_OutAppCCS,'<APPL_END_ADDR>', str(hex(appl_end_addr)))
#replacetextinFile(filename_OutAppCCS,'<FLEX_START_ADDR>', str(hex(flex_start_addr)))
#replacetextinFile(filename_OutAppCCS,'<FLEX_END_ADDR>', str(hex(flex_end_addr)))

replacetextinFile(filename_OutAppCCS,'<FLASH_BOOT_START_ADDR>', str(hex(flash_boot_start_addr)))
replacetextinFile(filename_OutAppCCS,'<FLASH_VECTORS_ADDR>', flash_vectors_addr)
replacetextinFile(filename_OutAppCCS,'<SHARED_VECTORS_SIZE>', str(hex(shared_vectors_size)))
#shared_vector_addr = int(flash_data[0],16) + int(flash_data[1],16) - shared_vectors_size
replacetextinFile(filename_OutAppCCS,'<SHARED_VECTORS_ADDR>', str(hex(shared_vector_addr)))

#replacetextinFile(filename_OutAppCCS,'<VECTOR_SIZE>', str(hex(vector_size)))

replacetextinFile(filename_OutAppCCS,'<APP_FLASH_LEN>', str(hex(vector_addr-appl_start_addr-3)))

if dual_image:
	if flex_type == 'download':
		if int(flash_data2[1],16)!=0:
			replacetextinFile(filename_OutAppCCS,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+' & 0x10000-'+str(hex(dual_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
		else:
			replacetextinFile(filename_OutAppCCS,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')		
		replacetextinFile(filename_OutAppCCS,'<APP_FLASH2_START>', ' ')
		replacetextinFile(filename_OutAppCCS,'<FLASH_SECTIONS>', '.text       : {} >> FLASH             \
		/* CODE                 */\n    .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ \n\
		      .const      : {} >> FLASH       /* CONSTANT DATA        */ \n')
		print('flex_type = download')
	else:
		replacetextinFile(filename_OutAppCCS,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & 0x10000-'+str(hex(flex_end_addr))+'*/\n/* Download area: '\
		+ str(hex(dual_start_addr))+'-'+str(hex(dual_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')		
		replacetextinFile(filename_OutAppCCS,'<APP_FLASH2_START>', 'FLASH2                  : origin = '\
		+str(hex(flex_start_addr))+', length = '+str(hex(flex_end_addr-flex_start_addr + 1)))
		replacetextinFile(filename_OutAppCCS,'<FLASH_SECTIONS>', ('#ifndef __LARGE_DATA_MODEL__\n'+ \
        '	.text       : {} >> FLASH            /* CODE                 */\n '+\
        '   #else \n'+\
        '	.text       : {} >> FLASH | FLASH2      /* CODE                 */\n'+\
        '    #endif \n'+\
		'       .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ \n'+\
        '    #ifndef __LARGE_DATA_MODEL__ \n' +\
		'      .const      : {} >> FLASH       /* CONSTANT DATA        */ \n'+\
		'    #else \n'+\
		'      .const      : {} >> FLASH2 | FLASH    /* CONSTANT DATA        */ \n '+\
		'   #endif \n'))
		print('flex_type = app')		
else:
	replacetextinFile(filename_OutAppCCS,'<BOOT1>', ' ')
	if int(flash_data2[1],16)==0:
		replacetextinFile(filename_OutAppCCS,'<APP_FLASH2_START>', ' ')
		replacetextinFile(filename_OutAppCCS,'<FLASH_SECTIONS>', '.text       : {} >> FLASH             \
		/* CODE                 */\n    .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ \n\
		      .const      : {} >> FLASH       /* CONSTANT DATA        */ \n')
		print('flex_type = download')
	else:
		replacetextinFile(filename_OutAppCCS,'<APP_FLASH2_START>', 'FLASH2                  : origin = '\
		+str(hex(flex_start_addr))+', length = '+str(hex(flex_end_addr-flex_start_addr + 1)))
		replacetextinFile(filename_OutAppCCS,'<FLASH_SECTIONS>', ('#ifndef __LARGE_DATA_MODEL__\n'+ \
        '	.text       : {} >> FLASH            /* CODE                 */\n '+\
        '   #else \n'+\
        '	.text       : {} >> FLASH | FLASH2      /* CODE                 */\n'+\
        '    #endif \n'+\
		'       .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ \n'+\
        '    #ifndef __LARGE_DATA_MODEL__ \n' +\
		'      .const      : {} >> FLASH       /* CONSTANT DATA        */ \n'+\
		'    #else \n'+\
		'      .const      : {} >> FLASH2 | FLASH    /* CONSTANT DATA        */ \n '+\
		'   #endif \n'))
		
app_reset_addr = appl_end_addr - 1
app_vector_table = ''
if memory_type =='FRAM':
	count=0
	count_addr=vector_addr
	while count_addr < app_reset_addr:
		app_vector_table = app_vector_table + 'INT' + str(count).zfill(2)+ '            : origin = '\
		+ str(hex(count_addr))+', length = 0x0002\n    '
		count+=1
		count_addr += 2		
else:
	app_vector_table = 'APP_VECTORS       : origin = 0x<VECTOR_ADDR>, length = <VECTOR_SIZE>'
	
replacetextinFile(filename_OutAppCCS,'<APP_VECTORS_MEM>', app_vector_table)
replacetextinFile(filename_OutAppCCS,'<VECTOR_SIZE>', vector_size)
replacetextinFile(filename_OutAppCCS,'<VECTOR_ADDR>', str(hex(vector_addr)))

#replacetextinFile(filename_OutAppCCS,'<RAM_LEN>', RAM_end_addr-)
replacetextinFile(filename_OutAppCCS,'<APP_FLASH_START>', str(hex(appl_start_addr+3)))

replacetextinFile(filename_OutAppCCS,'<FLASH_BOOT_LEN>', str(hex(shared_vector_addr-flash_boot_start_addr)))

replacetextinFile(filename_OutAppCCS,'<APP_RESET_VECTOR>', str(hex(app_reset_addr)))
app_vector_sections=''
if memory_type =='FRAM':
	app_vector_sections = getVectors(lnk_filename)
else:
	app_vector_sections='.APP_VECTORS : {} > APP_VECTORS /* INTERRUPT TABLE            */'

replacetextinFile(filename_OutAppCCS,'<APP_VECTORS_SECTIONS>', app_vector_sections)
##### Replace text in App IAR file#######################################################################################################
replacetextinFile(filename_OutAppIAR,'<DATE>', time_str)
replacetextinFile(filename_OutAppIAR,'<DEVICE>', device)
replacetextinFile(filename_OutAppIAR,'<RAM_START_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutAppIAR,'<RAM_END_ADDR>', str(hex(RAM_end_addr)))

replacetextinFile(filename_OutAppIAR,'<APPL_START_ADDR>', str(hex(appl_start_addr)))
if int(flash_data2[1],16)!=0:
	if dual_image:
		if flex_type == 'download':
			replacetextinFile(filename_OutAppIAR,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+' & 0x10000-'+str(hex(dual_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
#			print(hex(dual_end_addr))
			replacetextinFile(filename_OutAppIAR,'<FLEX_ADDRESS>', '\n    -D_Flex_Start=0x10000\n'+'    -D_Flex_End='+\
			str(hex(dual_end_addr)))
			replacetextinFile(filename_OutAppIAR,'<APPLICAION_AREA_DATA>', '-Z(CONST)DATA16_P,DATA20_P=_App_Start-_Appl_Vector_Start')
			replacetextinFile(filename_OutAppIAR,'<CODE_AREA>', '_App_Start-_Appl_Vector_Start')
			replacetextinFile(filename_OutAppIAR,'<DATA20_CODE_AREA>', '-Z(CONST)DATA20_C,DATA20_ID,CODE_ID=_App_Start-_Appl_Vector_Start')							
		else:
			replacetextinFile(filename_OutAppIAR,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & 0x10000-'+str(hex(flex_end_addr))+'*/\n/* Download area: '\
			+ str(hex(dual_start_addr))+'-'+str(hex(dual_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
			replacetextinFile(filename_OutAppIAR,'<FLEX_ADDRESS>', '\n    -D_Flex_Start=0x10000\n'+'    -D_Flex_End='+\
			str(hex(flex_end_addr)))
			replacetextinFile(filename_OutAppIAR,'<APPLICAION_AREA_DATA>', '-Z(CONST)DATA16_P,DATA20_P=_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')
			replacetextinFile(filename_OutAppIAR,'<CODE_AREA>', '_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')
			replacetextinFile(filename_OutAppIAR,'<DATA20_CODE_AREA>', '-Z(CONST)DATA20_C,DATA20_ID,CODE_ID=_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')			
		replacetextinFile(filename_OutAppIAR,'<APP_END_1>', str(hex(appl_end_addr)))				
	else:
		replacetextinFile(filename_OutAppIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & 0x10000-'+str(hex(flex_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')		
		replacetextinFile(filename_OutAppIAR,'<FLEX_ADDRESS>', '\n    -D_Flex_Start=0x10000\n'+'    -D_Flex_End='+\
		str(hex(flex_end_addr)))
		replacetextinFile(filename_OutAppIAR,'<APP_END_1>', '(__Boot_Start-1)')
		replacetextinFile(filename_OutAppIAR,'<APPLICAION_AREA_DATA>', '-Z(CONST)DATA16_P,DATA20_P=_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')
		replacetextinFile(filename_OutAppIAR,'<CODE_AREA>', '_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')
		replacetextinFile(filename_OutAppIAR,'<DATA20_CODE_AREA>', '-Z(CONST)DATA20_C,DATA20_ID,CODE_ID=_App_Start-_Appl_Vector_Start,0x10000-_Flex_End')		
#	replacetextinFile(filename_OutAppIAR,'<DATA_20>', '-Z(DATA)DATA20_I,DATA20_Z,DATA20_N')
	replacetextinFile(filename_OutAppIAR,'<DATA_HEAP_20>', '-Z(DATA)DATA20_HEAP+_DATA20_HEAP_SIZE')
						
else:
	if dual_image:
		replacetextinFile(filename_OutAppIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
		+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
		replacetextinFile(filename_OutAppIAR,'<APP_END_1>', str(hex(appl_end_addr)))		
	else:					
		replacetextinFile(filename_OutAppIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
		replacetextinFile(filename_OutAppIAR,'<APP_END_1>', '(__Boot_Start-1)')
	replacetextinFile(filename_OutAppIAR,'<FLEX_ADDRESS>', ' ')
#	replacetextinFile(filename_OutAppIAR,'<DATA_20>', ' ')
	replacetextinFile(filename_OutAppIAR,'<APPLICAION_AREA_DATA>', '-Z(CONST)DATA16_P=_App_Start-_Appl_Vector_Start')
	replacetextinFile(filename_OutAppIAR,'<DATA_HEAP_20>', ' ')	
	replacetextinFile(filename_OutAppIAR,'<CODE_AREA>', '_App_Start-_Appl_Vector_Start')
	replacetextinFile(filename_OutAppIAR,'<DATA20_CODE_AREA>', '-Z(CONST)DATA20_C,DATA20_ID,CODE_ID=_App_Start-_Appl_Vector_Start')
	
replacetextinFile(filename_OutAppIAR,'<FRAM_VECTORS_ADDR>', flash_vectors_addr)
replacetextinFile(filename_OutAppIAR,'<FRAM_BOOT_START_ADDR>', str(hex(flash_boot_start_addr)))
replacetextinFile(filename_OutAppIAR,'<SHARED_VECTORS_SIZE>', str(hex(shared_vectors_size)))
replacetextinFile(filename_OutAppIAR,'<VECTOR_ADDR>', str(hex(vector_addr)))

##### Replace text in Boot IAR file#######################################################################################################
replacetextinFile(filename_OutBootIAR,'<DATE>', time_str)
replacetextinFile(filename_OutBootIAR,'<DEVICE>', device)
replacetextinFile(filename_OutBootIAR,'<RAM_START_ADDR>', str(hex(RAM_start_addr)))
replacetextinFile(filename_OutBootIAR,'<RAM_END_ADDR>', str(hex(RAM_end_addr)))

replacetextinFile(filename_OutBootIAR,'<APPL_START_ADDR>', str(hex(appl_start_addr)))
if int(flash_data2[1],16)!=0:
	if dual_image:
		if flex_type == 'download':
			replacetextinFile(filename_OutBootIAR,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
			+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+' & 0x10000-'+str(hex(dual_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
			replacetextinFile(filename_OutBootIAR,'<FLEX_START_ADDR>', str(hex(flex_start_addr)))
			replacetextinFile(filename_OutBootIAR,'<DOWN_LOAD>', '-D_Down_Start=0x10000\n    -D_Down_End='+\
			str(hex(dual_end_addr)))	
			replacetextinFile(filename_OutBootIAR,'<APP_RESET_VECTOR>', '_Flex_Start')
			replacetextinFile(filename_OutBootIAR,'<Download AREA ADDRESSES>', '\
			-D_Down_Checksum=(_Flex_Start)\n\
			-D_Down_Start_Memory=(_Flex_Start+2)\n\
			-D_Down_CRC_Size1=(_Flex_End-_Down_Start_Memory+1)\n\
			-D_Down_CRC_Size2=(_Down_End-_Down_Start+1)\n\
			-D_Down_Offset_Size=(_Appl_Start+_Flex_End-_Flex_Start)\n\
			-D_Down_Offset1=(_Flex_Start-_Appl_Start)\n\
			-D_Down_Offset2=(_Down_Start+_Flex_Start-_Appl_Start-__Boot_Start)')									
		else:
			replacetextinFile(filename_OutBootIAR,'<BOOT1>', '\n/* App area     : '\
			+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & 0x10000-'+str(hex(flex_end_addr))+'*/\n/* Download area: '\
			+ str(hex(dual_start_addr))+'-'+str(hex(dual_end_addr))+\
			'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
			replacetextinFile(filename_OutBootIAR,'<FLEX_START_ADDR>', '0x10000')
			replacetextinFile(filename_OutBootIAR,'<DOWN_LOAD>', '-D_Down_Start='+str(hex(dual_start_addr))+'\n    -D_Down_End='+\
			str(hex(dual_end_addr)))
			replacetextinFile(filename_OutBootIAR,'<APP_RESET_VECTOR>', '__Boot_Start')
			replacetextinFile(filename_OutBootIAR,'<Download AREA ADDRESSES>', '\
			-D_Down_Checksum=(_Down_Start)\n\
			-D_Down_Start_Memory=(_Down_Start+2)\n\
			-D_Down_CRC_Size1=(_Down_End-_Down_Start_Memory+1)\n\
			-D_Down_CRC_Size2=0\n\
			-D_Down_Offset_Size=(__Boot_Start-1)\n\
			-D_Down_Offset1=(_Down_Start-_Appl_Start)\n\
			-D_Down_Offset2=(__Boot_Start-_Appl_Start+_Down_Start-_Flex_Start)')			
		replacetextinFile(filename_OutBootIAR,'<APP_END>', str(hex(appl_end_addr)))									
	else:					
		replacetextinFile(filename_OutBootIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+' & 0x10000-'+str(hex(flex_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
		replacetextinFile(filename_OutBootIAR,'<FLEX_START_ADDR>', '0x10000')
		replacetextinFile(filename_OutBootIAR,'<DOWN_LOAD>', ' ')
		replacetextinFile(filename_OutBootIAR,'<APP_END>', '(__Boot_Start-1)')
		replacetextinFile(filename_OutBootIAR,'<APP_RESET_VECTOR>', '__Boot_Start')
		replacetextinFile(filename_OutBootIAR,'<Download AREA ADDRESSES>', ' ')		
	replacetextinFile(filename_OutBootIAR,'<FLEX_END_ADDR>', str(hex(flex_end_addr)))
#	replacetextinFile(filename_OutBootIAR,'<DATA_20>', '-Z(DATA)DATA20_I,DATA20_Z,DATA20_N')
	replacetextinFile(filename_OutBootIAR,'<DATA_HEAP_20>', '-Z(DATA)DATA20_HEAP+_DATA20_HEAP_SIZE')	
else:
	if dual_image:	
		replacetextinFile(filename_OutBootIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+'*/\n/* Download area: '\
		+ str(hex(flex_start_addr))+'-'+str(hex(flex_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')
		replacetextinFile(filename_OutBootIAR,'<FLEX_START_ADDR>', str(hex(flex_start_addr)))
		replacetextinFile(filename_OutBootIAR,'<FLEX_END_ADDR>', str(hex(flex_end_addr)))
		replacetextinFile(filename_OutBootIAR,'<DOWN_LOAD>', '-D_Down_Start=0x10000\n    -D_Down_End=0xffffffff')
		replacetextinFile(filename_OutBootIAR,'<APP_END>', str(hex(appl_end_addr)))	
		replacetextinFile(filename_OutBootIAR,'<APP_RESET_VECTOR>', '_Flex_Start')
		replacetextinFile(filename_OutBootIAR,'<Download AREA ADDRESSES>', '\
		-D_Down_Checksum=(_Flex_Start)\n\
		-D_Down_Start_Memory=(_Flex_Start+2)\n\
		-D_Down_CRC_Size1=(_Flex_End-_Down_Start_Memory+1)\n\
		-D_Down_CRC_Size2=(_Down_End-_Down_Start+1)\n\
		-D_Down_Offset_Size=(_Appl_Start+_Flex_End-_Flex_Start)\n\
		-D_Down_Offset1=(_Flex_Start-_Appl_Start)\n\
		-D_Down_Offset2=(_Down_Start+_Flex_Start-_Appl_Start-__Boot_Start)')									
	else:					
		replacetextinFile(filename_OutBootIAR,'<BOOT1>', '\n/* App area     : '\
		+ str(hex(appl_start_addr))+'-'+str(hex(appl_end_addr))+\
		'*/\n/* Boot area    : '+str(hex(flash_boot_start_addr))+ '-0xffff*/\n')	
		replacetextinFile(filename_OutBootIAR,'<FLEX_START_ADDR>', '0')	
		replacetextinFile(filename_OutBootIAR,'<DOWN_LOAD>', ' ')
		replacetextinFile(filename_OutBootIAR,'<APP_END>', '(__Boot_Start-1)')
		replacetextinFile(filename_OutBootIAR,'<APP_RESET_VECTOR>', '__Boot_Start')	
		replacetextinFile(filename_OutBootIAR,'<Download AREA ADDRESSES>', ' ')			
		replacetextinFile(filename_OutBootIAR,'<FLEX_END_ADDR>', '0xffff')
#	replacetextinFile(filename_OutBootIAR,'<DATA_20>', ' ')	
	replacetextinFile(filename_OutBootIAR,'<DATA_HEAP_20>', ' ')
			
replacetextinFile(filename_OutBootIAR,'<FRAM_BOOT_START_ADDR>', str(hex(flash_boot_start_addr)))				
replacetextinFile(filename_OutBootIAR,'<FRAM_VECTORS_ADDR>', flash_vectors_addr)
replacetextinFile(filename_OutBootIAR,'<SHARED_VECTORS_SIZE>', str(hex(shared_vectors_size)))
replacetextinFile(filename_OutBootIAR,'<VECTOR_ADDR>', str(hex(vector_addr)))


		
print("The two linker files for boot side and application side are generated!")





